@@ -9,10 +9,10 @@ module ActionText
   end
 
   module VERSION
-    MAJOR = 7
-    MINOR = 2
-    TINY  = 2
-    PRE   = "1"
+    MAJOR = 8
+    MINOR = 0
+    TINY  = 4
+    PRE   = nil
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
